//	Copyright  2000.	GSI Technology
//					apps@gsitechnology.com
//  v 1.00  06/21/06    Jeff Daugherty  1) Created 
//
//

`timescale 1ps / 1ps

module G8342D37BD#(
		    parameter SPEED = 300,
                              A_bits = 1
)
  (A834, D, Q,  nBW, K, nK, nR, nW, nDoff, CQ, nCQ, QVLD, TMS, TDI, TDO, TCK );
   input [17:0] 	      A834; 		// address
   input 		      K;		// clock
   input 		      nK;		// clock
   input [3:0] 		      nBW;	
   input 		      nR; 	
   input 		      nW; 	
   input 		      nDoff; 	
   output 		      CQ; 	
   output 		      nCQ; 	
   output 		      QVLD; 	
   input [35:0] 	      D;		// data in
   inout [35:0] 	      Q;		// data out
   input 		      TMS;		// Scan Test Mode Select
   input 		      TDI;		// Scan Test Data In
   output 		      TDO;		// Scan Test Data Out
   input 		      TCK;		// Scan Test Clock

//---------------------------------------------------------------
// 	Scan Registers 
//---------------------------------------------------------------
   wire [3:0]	tBW;
   wire [17:0] 	A;
   assign 	A = A834;
   assign 	tBW = nBW;
   	
   parameter 	tCHQV     =  450;
   parameter 	tCHQX     = -450;
   parameter 	tCHQV_off =  2000;
   parameter 	tCHQX_off =  0;
   parameter 	tCQHQV    =  200;
   parameter 	tCQHQX    = -200;
   parameter    mem_size  =  A_bits > 1 ? A_bits : 20;
   parameter    mem_style =  A_bits > 1 ? "REDUCED" : "NORMAL";
   
   initial begin
      if (SPEED==400 | SPEED==375 | SPEED==333 | SPEED==300) begin
	 //do nothing
      end
      else begin
	 $display ("INVALID SPEED option, allowable SPEEDs options are 400, 375, 333, 300. SPEED = %d", SPEED);
	 $stop;
      end
   end
   core_b4_plus #( .A_size(18),
		   .A_bits(A_bits),
		   .DQ_width(36),
		   .RL(20),
		   .ECC(0),
		   .HighZ(36'bZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZ),
		   .bank_size(2**mem_size),
		   .mem_style(mem_style),
		   .mem_size(mem_size),
		   .tCHQV(tCHQV),
    		   .tCHQX(tCHQX),
    		   .tCQHQV(tCQHQV),
    		   .tCQHQX(tCQHQX),
    		   .tCHQV_off(tCHQV_off),
    		   .tCHQX_off(tCHQX_off))
     core_b4_plus( .A     (A),
		   .D     (D),
		   .Q     (Q),
		   .tBW   (tBW),
		   .K     (K),
		   .nK    (nK),
		   .nR    (nR),
		   .nW    (nW),
		   .nDoff (nDoff),
		   .CQ    (CQ),
		   .nCQ   (nCQ),
		   .QVLD  (QVLD),
		   .TCK   (TCK));

endmodule
